@@ -5,7 +5,7 @@
 /* *                                                                        * */
 /* * project   : libmng                                                     * */
 /* * file      : libmng_types.h            copyright (c) 2000 G.Juyn        * */
-/* * version   : 1.0.0                                                      * */
+/* * version   : 1.0.3                                                      * */
 /* *                                                                        * */
 /* * purpose   : type specifications                                        * */
 /* *                                                                        * */
@@ -91,6 +91,15 @@
 /* *             0.9.4 - 12/16/2000 - G.Juyn                                * */
 /* *             - fixed mixup of data- & function-pointers (thanks Dimitri)* */
 /* *                                                                        * */
+/* *             1.0.1 - 02/08/2001 - G.Juyn                                * */
+/* *             - added MEND processing callback                           * */
+/* *                                                                        * */
+/* *             1.0.2 - 06/23/2001 - G.Juyn                                * */
+/* *             - added processterm callback                               * */
+/* *                                                                        * */
+/* *             1.0.3 - 08/06/2001 - G.Juyn                                * */
+/* *             - changed inclusion of lcms.h for Linux platforms          * */
+/* *                                                                        * */
 /* ************************************************************************** */
 
 #ifndef _libmng_types_h_
@@ -143,10 +152,10 @@
 #ifndef ZLIB_DLL
 #undef FAR
 #endif
-#ifdef WIN32                           /* different header locations */
+#if defined(WIN32) || defined(linux)   /* different header locations */
 #include "lcms.h"
 #else
-#include "lcms/lcms.h"
+#include "lcms.h"
 #endif
 #endif /* MNG_INCLUDE_LCMS */
 
@@ -419,10 +428,18 @@ typedef mng_bool   (MNG_DECL *mng_processseek)   (mng_handle  hHandle,
                                                   mng_pchar   zName);
 typedef mng_bool   (MNG_DECL *mng_processneed)   (mng_handle  hHandle,
                                                   mng_pchar   zKeyword);
+typedef mng_bool   (MNG_DECL *mng_processmend)   (mng_handle  hHandle,
+                                                  mng_uint32  iIterationsdone,
+                                                  mng_uint32  iIterationsleft);
 typedef mng_bool   (MNG_DECL *mng_processunknown) (mng_handle  hHandle,
                                                    mng_chunkid iChunkid,
                                                    mng_uint32  iRawlen,
                                                    mng_ptr     pRawdata);
+typedef mng_bool   (MNG_DECL *mng_processterm)   (mng_handle  hHandle,
+                                                  mng_uint8   iTermaction,
+                                                  mng_uint8   iIteraction,
+                                                  mng_uint32  iDelay,
+                                                  mng_uint32  iItermax);
 
                                        /* display processing callbacks */
 typedef mng_ptr    (MNG_DECL *mng_getcanvasline) (mng_handle  hHandle,
